==> jc-1.4.0.tar.gz: soot/tagkit/SourceFileTag.h <==
// public class soot.tagkit.SourceFileTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class aeedf9bd83826ab2 soot_tagkit_SourceFileTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_SourceFileTag_H_
#define _JC_soot_tagkit_SourceFileTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_SourceFileTag$sub_refs	_jc_soot_tagkit_SourceFileTag$sub_refs;
typedef struct _jc_soot_tagkit_SourceFileTag$sub_nonrefs	_jc_soot_tagkit_SourceFileTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_SourceFileTag$refs	_jc_soot_tagkit_SourceFileTag$refs;
typedef struct _jc_soot_tagkit_SourceFileTag$nonrefs	_jc_soot_tagkit_SourceFileTag$nonrefs;
typedef struct _jc_soot_tagkit_SourceFileTag$object	_jc_soot_tagkit_SourceFileTag$object;

typedef const struct _jc_soot_tagkit_SourceFileTag$vmethods	_jc_soot_tagkit_SourceFileTag$vmethods;
typedef const struct _jc_soot_tagkit_SourceFileTag$vtable	_jc_soot_tagkit_SourceFileTag$vtable;
typedef const struct _jc_soot_tagkit_SourceFileTag$vtype	_jc_soot_tagkit_SourceFileTag$vtype;

// Constructors
extern void _jc_soot_tagkit_SourceFileTag$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceFileTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceFileTag$method$getSourceFile$11fee75c08dd840c(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *);
extern _jc_byte_array *_jc_soot_tagkit_SourceFileTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceFileTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_SourceFileTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_SourceFileTag$method_info$getSourceFile$11fee75c08dd840c;
extern _jc_method _jc_soot_tagkit_SourceFileTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_SourceFileTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_SourceFileTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *);
	struct _jc_java_lang_String$object	*(*getSourceFile$11fee75c08dd840c)(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *);
};

// Vtable
struct _jc_soot_tagkit_SourceFileTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_SourceFileTag$vmethods	soot_tagkit_SourceFileTag;
};

// Vtype
struct _jc_soot_tagkit_SourceFileTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_SourceFileTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_SourceFileTag$sub_refs {
	struct _jc_java_lang_String$object	*sourceFile;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_SourceFileTag$refs {
    _jc_soot_tagkit_SourceFileTag$sub_refs	soot_tagkit_SourceFileTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_SourceFileTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_SourceFileTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_SourceFileTag$sub_nonrefs	soot_tagkit_SourceFileTag;
};

// Object instance structure
struct _jc_soot_tagkit_SourceFileTag$object {
	_jc_soot_tagkit_SourceFileTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_SourceFileTag$vtype	*vtype;
	_jc_soot_tagkit_SourceFileTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_SourceFileTag$vtype _jc_soot_tagkit_SourceFileTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_SourceFileTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_SourceFileTag$class_object;

#endif	/* _JC_soot_tagkit_SourceFileTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/SourceFileTag.h <==
// public class soot.tagkit.SourceFileTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class aeedf9bd83826ab2 soot_tagkit_SourceFileTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_SourceFileTag_H_
#define _JC_soot_tagkit_SourceFileTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_SourceFileTag$sub_refs	_jc_soot_tagkit_SourceFileTag$sub_refs;
typedef struct _jc_soot_tagkit_SourceFileTag$sub_nonrefs	_jc_soot_tagkit_SourceFileTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_SourceFileTag$refs	_jc_soot_tagkit_SourceFileTag$refs;
typedef struct _jc_soot_tagkit_SourceFileTag$nonrefs	_jc_soot_tagkit_SourceFileTag$nonrefs;
typedef struct _jc_soot_tagkit_SourceFileTag$object	_jc_soot_tagkit_SourceFileTag$object;

typedef const struct _jc_soot_tagkit_SourceFileTag$vmethods	_jc_soot_tagkit_SourceFileTag$vmethods;
typedef const struct _jc_soot_tagkit_SourceFileTag$vtable	_jc_soot_tagkit_SourceFileTag$vtable;
typedef const struct _jc_soot_tagkit_SourceFileTag$vtype	_jc_soot_tagkit_SourceFileTag$vtype;

// Constructors
extern void _jc_soot_tagkit_SourceFileTag$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceFileTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceFileTag$method$getSourceFile$11fee75c08dd840c(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_SourceFileTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceFileTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_SourceFileTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_SourceFileTag$method_info$getSourceFile$11fee75c08dd840c;
extern _jc_method _jc_soot_tagkit_SourceFileTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_SourceFileTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_SourceFileTag$vmethods {
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSourceFile$11fee75c08dd840c)(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_SourceFileTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_SourceFileTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_SourceFileTag$vmethods	soot_tagkit_SourceFileTag;
};

// Vtype
struct _jc_soot_tagkit_SourceFileTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_SourceFileTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_SourceFileTag$sub_refs {
	struct _jc_java_lang_String$object	*sourceFile;
};

// Reference instance fields (object)
struct _jc_soot_tagkit_SourceFileTag$refs {
    _jc_soot_tagkit_SourceFileTag$sub_refs	soot_tagkit_SourceFileTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_SourceFileTag$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_SourceFileTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_SourceFileTag$sub_nonrefs	soot_tagkit_SourceFileTag;
};

// Object instance structure
struct _jc_soot_tagkit_SourceFileTag$object {
	_jc_soot_tagkit_SourceFileTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_SourceFileTag$vtype	*vtype;
	_jc_soot_tagkit_SourceFileTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_SourceFileTag$vtype _jc_soot_tagkit_SourceFileTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_SourceFileTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_SourceFileTag$class_object;

#endif	/* _JC_soot_tagkit_SourceFileTag_H_ */
